@@ -1,7 +1,7 @@
 class Feature(object):
 
     '''
-    Computing for Instrument.
+    Computing for Instrument Update
     '''
     @classmethod
     def computeForInstrument(cls, updateNum, time, featureParams, featureKey, instrumentManager):
@@ -15,3 +15,12 @@ class Feature(object):
     def computeForMarket(cls, updateNum, time, featureParams, featureKey, currentMarketFeatures, instrumentManager):
         raise NotImplementedError
         return None
+
+
+    '''
+    Computing for Instrument Data.
+    '''
+    @classmethod
+    def computeForInstrumentData(cls, updateNum, featureParams, featureKey, featureManager):
+        raise NotImplementedError
+        return None
